
Changelog
=========

0.4.2 (2022-06-15)
------------------

* Add Python support for Python 3.10 and drop support for 3.7
* Move CI from Appveyor and Travis to Github Actions
* Use `Black Code Style <https://black.readthedocs.io>`_ for oemof.tools
* Change default logging level for file logging from DEBUG to WARNING

0.4.1 (2021-02-21)
------------------

* Fix compatibility problem (by naming submodules in init script)


0.4.0 (2020-05-11)
------------------

* Move the code of the oemof.tools repository to a stand-alone repository.
* Use cookiecutter to create a wider testing structure and a more standardised
  package structure.
* Switch from nose to pytest
* Remove the version or commit logger
* Add test to increase test coverage
